@@ -317,6 +317,7 @@ class _Modeler:
         in relation to the root document and the pointer
         """
         url = meta.url(definition)
+        assert isinstance(url, str)
         pointer = meta.pointer(definition)
         return self.get_relative_url(url), pointer
 
@@ -704,7 +705,8 @@ class _Modeler:
         self._traversed_relative_urls_pointers = set()
         for definition in tuple(
             self._traverse_model_definitions(
-                self.root, (OpenAPI,)
+                self.root,
+                (OpenAPI,)
             )
         ):
             yield self._resolve(definition)
@@ -1071,9 +1073,10 @@ class Module:
         """
         # Make sure that any matching, existing classes use the same names
         self._parse_existing_module(path)
+        model_source: str = str(self)
         # Save the module
         with open(path, 'w') as model_io:
-            model_io.write(str(self))
+            model_io.write(model_source)
 
     def __eq__(self, other):
         # type: (Module) -> bool
